if
--
This directory was created in response to a bug in the code generation of
else statements, and so this directory was therefore created to test the case 
of not having an else.

This directory was created to test/check this. I'm leaving it here to allow
testing for regression. It also acts as a simple example of how pyxie programs
can be written, compiled etc.
